==> sumika-0.05.tar.gz: sumika-0.05/gtk2/topwin.h <==
/*
 *  topwin.h
 *  Copyright(C) 2003- Masahito Omote <omote@utyuuzin.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __TOPWIN_H__
#define __TOPWIN_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "anthycontainer.h"
#include "skkcontainer.h"
#include "cannacontainer.h"

typedef struct topwindow {
	GtkWidget *window;
	GtkWidget *menubar;
	AnthyContainer *anthycontainer;
	SKKContainer *skkcontainer;
	CannaContainer *cannacontainer;
	GtkWidget *bt_end;
} TopWindow;

typedef enum {
	MAIN_MENU_FILE_QUIT
} MenuFileItem;

typedef enum {
	MAIN_MENU_OPTION_ANTHY,
	MAIN_MENU_OPTION_SKK,
	MAIN_MENU_OPTION_CANNA,
	MAIN_MENU_OPTION_PRIME
} MenuOptionItem;

typedef enum {
	MAIN_MENU_HELP_ABOUT
} MenuHelpItem;

// extern int cb_destroy_topwindow(GtkWidget *widget, void *data);
extern int create_topwindow(TopWindow *win);
extern int show_topwindow(TopWindow *win);

#endif /* __TOPWIN_H__ */

==> sumika-0.07.tar.gz: sumika-0.07/gtk2/topwin.h <==
/*
 *  topwin.h
 *  Copyright(C) 2003- Masahito Omote <omote@utyuuzin.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __TOPWIN_H__
#define __TOPWIN_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "anthycontainer.h"
#include "skkcontainer.h"
#include "cannacontainer.h"
#include "addwordpane.h"

typedef struct topwindow {
    GtkWidget *window;
    GtkWidget *menubar;
    AnthyContainer *anthycontainer;
    SKKContainer *skkcontainer;
    CannaContainer *cannacontainer;
    GtkWidget *addwordpane;
    GtkWidget *bt_end;
} TopWindow;

typedef enum {
    MAIN_MENU_FILE_QUIT
} MenuFileItem;

typedef enum {
    MAIN_MENU_OPTION_ANTHY,
    MAIN_MENU_OPTION_SKK,
    MAIN_MENU_OPTION_CANNA,
    MAIN_MENU_OPTION_PRIME,
    MAIN_MENU_OPTION_INTEGRATE,
} MenuOptionItem;

typedef enum {
    MAIN_MENU_HELP_ABOUT,
} MenuHelpItem;

// extern int cb_destroy_topwindow(GtkWidget *widget, void *data);
extern int create_topwindow(TopWindow *win);
extern int show_topwindow(TopWindow *win);

#endif /* __TOPWIN_H__ */
